@@ -122,19 +122,17 @@ class SQLiteLibrary(local.Library):
     def add(self, track):
         try:
             track = self._validate_track(track)
-        except ValueError as e:
-            logger.warn('Skipped %s: %s', track.uri, e)
-            return
-        if self._config['extract_images']:
             album = track.album
-            # TBD: how to handle track w/o album?
-            if album and not album.images:
+            # tracks w/o albums: wait for Mopidy's infamous "meta data model"
+            if self._config['extract_images'] and album and not album.images:
                 try:
                     album = album.copy(images=self._extract_images(track))
                 except Exception as e:
                     logger.warn('Extracting images from %s: %s', track.uri, e)
             track = track.copy(album=album)
-        schema.insert_track(self._connect(), track)
+            schema.insert_track(self._connect(), track)
+        except Exception as e:
+            logger.warn('Skipped %s: %s', track.uri, e)
 
     def remove(self, uri):
         schema.delete_track(self._connect(), uri)
@@ -219,7 +217,9 @@ class SQLiteLibrary(local.Library):
         if track.name:
             name = track.name
         else:
-            name = urllib.unquote(_TRACK_URI_RE.match(track.uri).group(2))
+            logger.debug('%s: no track name', track.uri)
+            basename = str(_TRACK_URI_RE.match(track.uri).group(2))
+            name = self._decode(urllib.unquote(basename))
         if track.album and track.album.name:
             album = self._validate_album(track.album)
         else:
@@ -232,6 +232,14 @@ class SQLiteLibrary(local.Library):
             performers=map(self._validate_artist, track.performers)
         )
 
+    def _decode(self, string):
+        for encoding in self._config['encodings']:
+            try:
+                return string.decode(encoding)
+            except UnicodeError:
+                pass
+        raise UnicodeError('No matching encoding found for %r' % string)
+
     def _extract_images(self, track):
         import imghdr
         # FIXME: internal Mopidy APIs
